@@ -1,8 +1,8 @@
 # --
 # Kernel/Config/Defaults.pm - Default Config file for OTRS kernel
-# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2006 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: Defaults.pm,v 1.210 2005/08/19 17:31:37 cs Exp $
+# $Id: Defaults.pm,v 1.222.2.11 2006/07/07 12:46:11 cs Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -23,7 +23,7 @@ package Kernel::Config::Defaults;
 use strict;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.210 $';
+$VERSION = '$Revision: 1.222.2.11 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -92,7 +92,7 @@ sub LoadDefaults {
     # (The database DSN for MySQL ==> more: "man DBD::mysql")
     $Self->{DatabaseDSN} = "DBI:mysql:database=<OTRS_CONFIG_Database>;host=<OTRS_CONFIG_DatabaseHost>;";
 
-    # (The database DSN for PostgrSQL ==> more: "man DBD::Pg")
+    # (The database DSN for PostgreSQL ==> more: "man DBD::Pg")
 #    $Self->{DatabaseDSN} = "DBI:Pg:dbname=<OTRS_CONFIG_Database>;host=<OTRS_CONFIG_DatabaseHost>;";
 
     # (The database DSN for DBI:ODBC ==> more: "man DBD::ODBC")
@@ -106,6 +106,7 @@ sub LoadDefaults {
 #    $Self->{DatabaseDSN} = "DBI:Oracle:sid=vingador;host=vingador;port=1521;";
     # if needed, oracle env settings
 #    $ENV{ORACLE_HOME} = '/opt/ora9/product/9.2';
+
 #    $ENV{ORACLE_HOME} = '/oracle/Ora92';
 #    $ENV{NLS_DATE_FORMAT} = 'YYYY-MM-DD HH24:MI:SS';
 #    $ENV{NLS_LANG} = "german_germany.we8iso8859p15";
@@ -123,10 +124,10 @@ sub LoadDefaults {
     # [default: iso-8859-1]
     $Self->{DefaultCharset} = 'iso-8859-1';
 #    $Self->{DefaultCharset} = 'utf-8';
-    # default langauge
-    # (the default frontend langauge) [default: en]
+    # default language
+    # (the default frontend language) [default: en]
     $Self->{DefaultLanguage} = 'en';
-    # used langauges
+    # used languages
     # (short name = long name and file)
     $Self->{DefaultUsedLanguages} = {
 #            bb => 'Bavarian',
@@ -136,6 +137,7 @@ sub LoadDefaults {
             fr => 'Fran&ccedil;ais',
             bg => 'Bulgarian',
             fi => 'Suomi',
+            el => 'Greek',
             es => 'Espa&ntilde;ol',
             pt_BR => 'Portugu&ecirc;s Brasileiro',
             pt => 'Portugu&ecirc;s',
@@ -146,11 +148,12 @@ sub LoadDefaults {
             nb_NO => 'Norsk bokm&aring;l',
             sv => 'Svenska',
             hu => 'Hungarian',
-            th => 'Thai',
-#            da => 'Dansk',
+            zh_CN => 'Simplified Chinese',
+#            th => 'Thai',
+            da => 'Dansk',
 #            ro => 'Romanian',
 #            hr => 'Croatian',
-#            sk => 'Slovak',
+            sk_SK => 'Slovak',
 #            sl => 'Slovenian',
 #            tr => 'tr',
 #            jp => 'jp',
@@ -159,6 +162,13 @@ sub LoadDefaults {
     # (the default html theme) [default: Standard]
     $Self->{DefaultTheme} = 'Standard';
 
+    # DefaultTheme::HostBased
+    # (set theme based on host name)
+#    $Self->{'DefaultTheme::HostBased'} = {
+#        'host1\.example\.com' => 'SomeTheme1',
+#        'host2\.example\.com' => 'SomeTheme1',
+#    };
+
     # DefaultViewNewLine
     # (insert new line in text messages after max x chars and
     # the next word)
@@ -180,11 +190,15 @@ sub LoadDefaults {
     $Self->{ShowAlwaysLongTime} = 0;
     $Self->{TimeShowAlwaysLong} = 0;
 
+    # TimeInputFormat
+    # (default date input format) [Option|Input]
+    $Self->{TimeInputFormat} = 'Option';
+
     # AttachmentDownloadType
     # (if the tickets attachments will be opened in browser or just to
     # force the download) [attachment|inline]
-    $Self->{'AttachmentDownloadType'} = 'inline';
-#    $Self->{'AttachmentDownloadType'} = 'attachment';
+#    $Self->{'AttachmentDownloadType'} = 'inline';
+    $Self->{'AttachmentDownloadType'} = 'attachment';
 
     # --------------------------------------------------- #
     # Check Settings
@@ -255,7 +269,7 @@ sub LoadDefaults {
     # SendmailNotificationEnvelopeFrom
     # Set a email address that is used as envelope from header in outgoing
     # notifications
-    $Self->{'SendmailNotificationEnvelopeFrom'} = '';
+#    $Self->{'SendmailNotificationEnvelopeFrom'} = '';
 
     # --------------------------------------------------- #
     # authentication settings                             #
@@ -321,12 +335,18 @@ sub LoadDefaults {
 
     # UserSyncLDAPMap
     # (map if agent should create/synced from LDAP to DB after login)
-    $Self->{UserSyncLDAPMap} = {
-        # DB -> LDAP
-        Firstname => 'givenName',
-        Lastname => 'sn',
-        Email => 'mail',
-    };
+#    $Self->{UserSyncLDAPMap} = {
+#        # DB -> LDAP
+#        Firstname => 'givenName',
+#        Lastname => 'sn',
+#        Email => 'mail',
+#    };
+    # UserSyncLDAPGroups
+    # (If "LDAP" was selected for AuthModule, you can specify inital
+    # user groups for first login.)
+#    $Self->{UserSyncLDAPGroups} = [
+#        'users',
+#    ];
 
     # UserTable
     $Self->{DatabaseUserTable} = 'system_user';
@@ -430,7 +450,7 @@ sub LoadDefaults {
 
     # SessionMaxTime
     # (Max valid time of one session id in second (8h = 28800).)
-    $Self->{SessionMaxTime} = 9*60*60;
+    $Self->{SessionMaxTime} = 10*60*60;
 
     # SessionMaxIdleTime
     # (After this time (in seconds) without new http request, then
@@ -495,7 +515,7 @@ sub LoadDefaults {
 
     $Self->{'TimeVacationDays'} = {
         1 => {
-            01 => 'New Year\'s Eve!',
+            1 => 'New Year\'s Eve!',
         },
         5 => {
             1 => '1 St. May',
@@ -514,18 +534,18 @@ sub LoadDefaults {
 
     $Self->{'TimeVacationDaysOneTime'} = {
 #        2004 => {
-#          6 => {
-#              07 => 'Some Day',
-#          },
-#          12 => {
-#              24 => 'Some A Day',
-#              31 => 'Some B Day',
-#          },
+#            6 => {
+#                7 => 'Some Day',
+#            },
+#            12 => {
+#                24 => 'Some A Day',
+#                31 => 'Some B Day',
+#            },
 #        },
 #        2005 => {
-#          1 => {
-#              11 => 'Some Day',
-#          },
+#            1 => {
+#                11 => 'Some Day',
+#            },
 #        },
     };
 
@@ -561,6 +581,10 @@ sub LoadDefaults {
     # be changed on agent frontend.)
     $Self->{DemoSystem} = 0;
 
+    # SwitchToUser
+    # (Allow the admin to switch into a selected user session.)
+    $Self->{SwitchToUser} = 0;
+
     # --------------------------------------------------- #
     # MIME-Viewer for online to html converter
     # --------------------------------------------------- #
@@ -643,7 +667,7 @@ sub LoadDefaults {
     #$ENV{HOME} = '/var/lib/wwwrun';
     $Self->{'SMIME::Bin'} = '/usr/bin/openssl';
 #    $Self->{'SMIME::CertPath'} = '/etc/ssl/certs';
-#    $Self->{'SMIME::PrivatePath'} = '/etc/ssl/private/private';
+#    $Self->{'SMIME::PrivatePath'} = '/etc/ssl/private';
 
     # --------------------------------------------------- #
     # system permissions
@@ -975,7 +999,7 @@ Your OTRS Notification Master
         CustomerValid => 'valid_id',
         CustomerUserListFields => ['first_name', 'last_name', 'email'],
 #        CustomerUserListFields => ['login', 'first_name', 'last_name', 'customer_id', 'email'],
-        CustomerUserSearchFields => ['login', 'last_name', 'customer_id'],
+        CustomerUserSearchFields => ['login', 'first_name', 'last_name', 'customer_id'],
         CustomerUserSearchPrefix => '',
         CustomerUserSearchSuffix => '*',
         CustomerUserSearchListLimit => 250,
@@ -1241,6 +1265,10 @@ Your OTRS Notification Master
         Description => 'Address book of CustomerUser sources',
         Title => 'Address Book',
     };
+    $Self->{'Frontend::Module'}->{'AgentLookup'} = {
+        Description => 'Data table lookup module.',
+        Title => 'Lookup',
+    };
     $Self->{'Frontend::Module'}->{'AgentLinkObject'} = {
         Description => 'Link Object',
         Title => 'Link Object',
@@ -1254,24 +1282,7 @@ Your OTRS Notification Master
         NavBarName      => '',
         Title           => 'Calendar',
     };
-    # stats
-    $Self->{'Frontend::Module'}->{'SystemStats'} = {
-        GroupRo => ['stats'],
-        Description => 'Stats',
-        Title => 'Stats',
-        NavBarName => 'Ticket',
-        NavBar => [
-          {
-            Description => 'Stats-Area',
-            Name => 'Stats',
-            Image => 'stats.png',
-            Link => 'Action=SystemStats',
-            NavBar => 'Ticket',
-            Prio => 400,
-            AccessKey => 't',
-          },
-        ],
-    };
+
     # admin interface
     $Self->{'Frontend::Module'}->{'Admin'} = {
         Group => ['admin'],
@@ -1676,9 +1687,14 @@ sub new {
             }
         }
         else {
-            print STDERR "ERROR: Can't read $Self->{Home}/RELEASE: $!";
+            print STDERR "ERROR: Can't read $Self->{Home}/RELEASE: $! This file is needed by central system parts of OTRS, the system will not work without this file.\n";
+            die;
         }
     }
+    else {
+        print STDERR "ERROR: $Self->{Home}/RELEASE does not exist! This file is needed by central system parts of OTRS, the system will not work without this file.\n";
+        die;
+    }
     # load config (again)
     $Self->Load();
 
@@ -1714,6 +1730,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.210 $ $Date: 2005/08/19 17:31:37 $
+$Revision: 1.222.2.11 $ $Date: 2006/07/07 12:46:11 $
 
 =cut
