@@ -1,11 +1,11 @@
 # --
 # Kernel/System/StdResponse.pm - lib for std responses
-# Copyright (C) 2002-2003 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2006 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: StdResponse.pm,v 1.7 2003/03/13 17:20:46 martin Exp $
+# $Id: StdResponse.pm,v 1.11.2.2 2006/07/07 07:44:35 rk Exp $
 # --
-# This software comes with ABSOLUTELY NO WARRANTY. For details, see 
-# the enclosed file COPYING for license information (GPL). If you 
+# This software comes with ABSOLUTELY NO WARRANTY. For details, see
+# the enclosed file COPYING for license information (GPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 # --
 
@@ -14,7 +14,7 @@ package Kernel::System::StdResponse;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.7 $';
+$VERSION = '$Revision: 1.11.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -23,7 +23,7 @@ sub new {
     my %Param = @_;
 
     # allocate new hash for object
-    my $Self = {}; 
+    my $Self = {};
     bless ($Self, $Type);
 
     # get common opjects
@@ -42,26 +42,27 @@ sub new {
 sub StdResponseAdd {
     my $Self = shift;
     my %Param = @_;
-    # --
     # check needed stuff
-    # --
     foreach (qw(Name ValidID Response UserID)) {
       if (!defined($Param{$_})) {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
         return;
       }
     }
-    # --
+    if ($Param{Name} eq '') {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need Name!");
+        return;
+    }
     # db quote
-    # --
-    foreach (keys %Param) {
+    foreach (qw(Name Comment Response)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
-    # --
+    foreach (qw(ValidID UserID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     # sql
-    # --
     my $SQL = "INSERT INTO standard_response ".
-        " (name, valid_id, comment, text, ".
+        " (name, valid_id, comments, text, ".
         " create_time, create_by, change_time, change_by)".
         " VALUES ".
         " ('$Param{Name}', $Param{ValidID}, '$Param{Comment}', '$Param{Response}', ".
@@ -70,7 +71,7 @@ sub StdResponseAdd {
         my $Id = 0;
         $Self->{DBObject}->Prepare(
             SQL => "SELECT id FROM standard_response WHERE ".
-              "name = '$Param{Name}' AND text = '$Param{Response}'",
+              "name = '$Param{Name}' AND text like '$Param{Response}'",
         );
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
             $Id = $Row[0];
@@ -85,17 +86,17 @@ sub StdResponseAdd {
 sub StdResponseGet {
     my $Self = shift;
     my %Param = @_;
-    # --
     # check needed stuff
-    # --
     if (!$Param{ID}) {
       $Self->{LogObject}->Log(Priority => 'error', Message => "Need ID!");
       return;
     }
-    # --
-    # sql 
-    # --
-    my $SQL = "SELECT name, valid_id, comment, text ".
+    # db quote
+    foreach (qw(ID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
+    # sql
+    my $SQL = "SELECT name, valid_id, comments, text ".
         " FROM ".
         " standard_response ".
         " WHERE ".
@@ -104,7 +105,7 @@ sub StdResponseGet {
         return;
     }
     if (my @Data = $Self->{DBObject}->FetchrowArray()) {
-        my %Data = ( 
+        my %Data = (
             ID => $Param{ID},
             Name => $Data[0],
             Comment => $Data[2],
@@ -113,7 +114,28 @@ sub StdResponseGet {
         );
         return %Data;
     }
-    else { 
+    else {
+        return;
+    }
+}
+# --
+sub StdResponseDelete {
+    my $Self = shift;
+    my %Param = @_;
+    # check needed stuff
+    if (!$Param{ID}) {
+      $Self->{LogObject}->Log(Priority => 'error', Message => "Need ID!");
+      return;
+    }
+    # db quote
+    foreach (qw(ID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
+    # sql
+    if ($Self->{DBObject}->Prepare(SQL => "DELETE FROM standard_response WHERE ID = $Param{ID}")) {
+        return 1;
+    }
+    else {
         return;
     }
 }
@@ -121,29 +143,26 @@ sub StdResponseGet {
 sub StdResponseUpdate {
     my $Self = shift;
     my %Param = @_;
-    # --
     # check needed stuff
-    # --
     foreach (qw(ID Name ValidID Response UserID)) {
       if (!defined($Param{$_})) {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
         return;
       }
     }
-    # --
     # db quote
-    # --
-    foreach (keys %Param) {
-            $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
+    foreach (qw(Name Comment Response)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
+    }
+    foreach (qw(ID ValidID UserID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
-    # --
     # sql
-    # --
     my $SQL = "UPDATE standard_response SET " .
         " name = '$Param{Name}', " .
         " text = '$Param{Response}', " .
-        " comment = '$Param{Comment}', " .
-        " valid_id = $Param{ValidID}, " . 
+        " comments = '$Param{Comment}', " .
+        " valid_id = $Param{ValidID}, " .
         " change_time = current_timestamp, " .
         " change_by = $Param{UserID} " .
         " WHERE " .
@@ -175,27 +194,23 @@ sub StdResponseLookup {
     if ($Param{StdResponse} && $Self->{"StdResponseLookup$Param{StdResponse}"}) {
         return $Self->{"StdResponseLookup$Param{StdResponse}"};
     }
-    # --
     # get data
-    # --
     my $SQL = '';
     my $Suffix = '';
     if ($Param{StdResponse}) {
         $Suffix = 'StdResponseID';
-        $SQL = "SELECT id FROM standard_response WHERE name = '$Param{StdResponse}'";
+        $SQL = "SELECT id FROM standard_response WHERE name = '".$Self->{DBObject}->Quote($Param{StdResponse})."'";
     }
     else {
         $Suffix = 'StdResponse';
-        $SQL = "SELECT name FROM standard_response WHERE id = $Param{StdResponseID}";
+        $SQL = "SELECT name FROM standard_response WHERE id = ".$Self->{DBObject}->Quote($Param{StdResponseID}, 'Integer')."";
     }
     $Self->{DBObject}->Prepare(SQL => $SQL);
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
         # store result
         $Self->{"StdResponse$Suffix"} = $Row[0];
     }
-    # --
     # check if data exists
-    # --
     if (!exists $Self->{"StdResponse$Suffix"}) {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Found no \$$Suffix!");
         return;
@@ -210,15 +225,13 @@ sub GetAllStdResponses {
     if (!defined $Param{Valid}) {
         $Param{Valid} = 1;
     }
-    # --
     # return data
-    # --
     return $Self->{DBObject}->GetTableData(
         Table => 'standard_response',
         What => 'id, name',
         Valid => $Param{Valid},
     );
-}   
+}
 # --
 
 1;
