@@ -2,7 +2,7 @@
 # Kernel/System/Ticket/ArticleStorageFS.pm - article storage module for OTRS kernel
 # Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: ArticleStorageFS.pm,v 1.22 2005/07/31 08:10:06 martin Exp $
+# $Id: ArticleStorageFS.pm,v 1.28.2.2 2005/12/30 12:22:57 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -23,7 +23,7 @@ use MIME::Base64;
 umask 002;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.22 $';
+$VERSION = '$Revision: 1.28.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -40,13 +40,13 @@ sub ArticleStorageInit {
     $Self->{ArticleContentPath} = $Year.'/'.$Month.'/'.$Day;
 
     # check fs write permissions!
-    my $Path = "$Self->{ArticleDataDir}/$Self->{ArticleContentPath}/check_permissons.$$";
+    my $Path = "$Self->{ArticleDataDir}/$Self->{ArticleContentPath}/check_permissions.$$";
     if (-d $Path) {
         File::Path::rmtree([$Path]) || die "Can't remove $Path: $!\n";
     }
-    if (mkdir("$Self->{ArticleDataDir}/check_permissons_$$", 022)) {
-        if (!rmdir("$Self->{ArticleDataDir}/check_permissons_$$")) {
-            die "Can't remove $Self->{ArticleDataDir}/check_permissons_$$: $!\n";
+    if (mkdir("$Self->{ArticleDataDir}/check_permissions_$$", 022)) {
+        if (!rmdir("$Self->{ArticleDataDir}/check_permissions_$$")) {
+            die "Can't remove $Self->{ArticleDataDir}/check_permissions_$$: $!\n";
         }
         if (File::Path::mkpath([$Path], 0, 0775)) {
             File::Path::rmtree([$Path]) || die "Can't remove $Path: $!\n";
@@ -56,10 +56,10 @@ sub ArticleStorageInit {
         my $Error = $!;
         $Self->{LogObject}->Log(
             Priority => 'notice',
-            Message => "Can't create $Self->{ArticleDataDir}/check_permissons_$$: $Error, ".
+            Message => "Can't create $Self->{ArticleDataDir}/check_permissions_$$: $Error, ".
             "Try: \$OTRS_HOME/bin/SetPermissions.sh !",
         );
-        die "Error: Can't create $Self->{ArticleDataDir}/check_permissons_$$: $Error \n\n ".
+        die "Error: Can't create $Self->{ArticleDataDir}/check_permissions_$$: $Error \n\n ".
             "Try: \$OTRS_HOME/bin/SetPermissions.sh !!!\n";
     }
     return 1;
@@ -78,6 +78,11 @@ sub ArticleDelete {
     # delete attachments and plain emails
     my @Articles = $Self->ArticleIndex(TicketID => $Param{TicketID});
     foreach (@Articles) {
+        # delete time accounting
+        $Self->ArticleAccountedTimeDelete(
+            ArticleID => $_,
+            UserID => $Param{UserID},
+        );
         # delete attachments
         $Self->ArticleDeleteAttachment(
             ArticleID => $_,
@@ -88,8 +93,16 @@ sub ArticleDelete {
             ArticleID => $_,
             UserID => $Param{UserID},
         );
+        # delete storage directory
+        $Self->_ArticleDeleteDirectory(
+            ArticleID => $_,
+            UserID => $Param{UserID},
+        );
     }
     # delete articles
+    foreach (qw(TicketID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     if ($Self->{DBObject}->Do(SQL => "DELETE FROM article WHERE ticket_id = $Param{TicketID}")) {
         # delete history
         if ($Self->HistoryDelete(TicketID => $Param{TicketID}, UserID => $Param{UserID})) {
@@ -103,6 +116,32 @@ sub ArticleDelete {
         return;
     }
 }
+# --
+sub _ArticleDeleteDirectory {
+    my $Self = shift;
+    my %Param = @_;
+    # check needed stuff
+    foreach (qw(ArticleID UserID)) {
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
+    }
+    # delete directory from fs
+    my $ContentPath = $Self->ArticleGetContentPath(ArticleID => $Param{ArticleID});
+    my $Path = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}";
+    if (-d $Path) {
+        if (! rmdir($Path)) {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message => "Can't remove: $Path: $!!",
+            );
+            return;
+        }
+    }
+    return 1;
+}
+# --
 sub ArticleDeletePlain {
     my $Self = shift;
     my %Param = @_;
@@ -114,12 +153,21 @@ sub ArticleDeletePlain {
       }
     }
     # delete attachments
+    foreach (qw(ArticleID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     $Self->{DBObject}->Do(SQL => "DELETE FROM article_plain WHERE article_id = $Param{ArticleID}");
     # delete from fs
     my $ContentPath = $Self->ArticleGetContentPath(ArticleID => $Param{ArticleID});
-    my $Path = "$Self->{ArticleDataDir}/$ContentPath/plain.txt";
-    if (-f $Path) {
-        unlink $Path;
+    my $File = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/plain.txt";
+    if (-f $File) {
+        if (!unlink($File)) {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message => "Can't remove: $File: $!!",
+            );
+            return;
+        }
     }
     return 1;
 }
@@ -135,15 +183,25 @@ sub ArticleDeleteAttachment {
       }
     }
     # delete attachments
+    foreach (qw(ArticleID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     $Self->{DBObject}->Do(SQL => "DELETE FROM article_attachment WHERE article_id = $Param{ArticleID}");
     # delete from fs
     my $ContentPath = $Self->ArticleGetContentPath(ArticleID => $Param{ArticleID});
-    my $Path = "$Self->{ArticleDataDir}/$ContentPath/";
-    my @List = glob($Path);
-    foreach my $File (@List) {
-        $File =~ s!^.*/!!;
-        if ($File !~ /^plain.txt$/) {
-            unlink "$Path/$File";
+    my $Path = "$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}";
+    if (-e $Path) {
+        my @List = glob($Path."/*");
+        foreach my $File (@List) {
+            $File =~ s!^.*/!!;
+            if ($File !~ /^plain.txt$/) {
+                if (!unlink "$Path/$File") {
+                    $Self->{LogObject}->Log(
+                        Priority => 'error',
+                        Message => "Can't remove: $Path/$File: $!!",
+                    );
+                }
+            }
         }
     }
     return 1;
@@ -199,23 +257,31 @@ sub ArticleWriteAttachment {
     # prepare/filter ArticleID
     $Param{ArticleID} = quotemeta($Param{ArticleID});
     $Param{ArticleID} =~ s/\0//g;
+    my $ContentPath = $Self->ArticleGetContentPath(ArticleID => $Param{ArticleID});
     # define path
-    $Param{Path} = $Self->{ArticleDataDir}.'/'.$Self->{ArticleContentPath}.'/'.$Param{ArticleID};
+    $Param{Path} = $Self->{ArticleDataDir}.'/'.$ContentPath.'/'.$Param{ArticleID};
     # check used name (we want just uniq names)
-    my $NewFileName = decode_mimewords($Param{Filename});
+    $Param{Filename} = decode_mimewords($Param{Filename});
+    # strip spaces from filenames
+    $Param{Filename} =~ s/ /_/g;
+    # strip dots from filenames
+    $Param{Filename} =~ s/^\.//g;
+    my $NewFileName = $Param{Filename};
     my %UsedFile = ();
-    my @Index = $Self->ArticleAttachmentIndex(
+    my %Index = $Self->ArticleAttachmentIndex(
         ArticleID => $Param{ArticleID},
     );
-    foreach (@Index) {
-        $UsedFile{$_} = 1;
+    foreach (keys %Index) {
+        $UsedFile{$Index{$_}->{Filename}} = 1;
     }
     for (my $i=1; $i<=12; $i++) {
         if (exists $UsedFile{$NewFileName}) {
-            $NewFileName = "$Param{Filename}-$i";
-        }
-        else {
-            $i = 20;
+            if ($Param{Filename} =~ /^(.*)\.(.+?)$/) {
+               $NewFileName = "$1-$i.$2";
+            }
+            else {
+               $NewFileName = "$Param{Filename}-$i";
+            }
         }
     }
     $Param{Filename} = $NewFileName;
@@ -261,9 +327,12 @@ sub ArticlePlain {
     if (!open (DATA, "< $Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/plain.txt")) {
         # can't open article
         # try database
+        foreach (qw(ArticleID)) {
+            $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+        }
         my $SQL = "SELECT body FROM article_plain ".
-        " WHERE ".
-        " article_id = ".$Self->{DBObject}->Quote($Param{ArticleID})."";
+          " WHERE ".
+          " article_id = $Param{ArticleID}";
         $Self->{DBObject}->Prepare(SQL => $SQL);
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
             $Data = $Row[0];
@@ -273,8 +342,8 @@ sub ArticlePlain {
         }
         else {
             $Self->{LogObject}->Log(
-              Priority => 'error',
-              Message => "Can't open $Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/plain.txt: $!",
+                Priority => 'error',
+                Message => "Can't open $Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/plain.txt: $!",
             );
             return;
         }
@@ -300,17 +369,16 @@ sub ArticleAttachmentIndex {
     }
     # check needed stuff
     if (!$Param{ArticleID}) {
-      $Self->{LogObject}->Log(Priority => 'error', Message => "Need ArticleID!");
-      return;
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need ArticleID!");
+        return;
     }
     my $ContentPath = $Self->ArticleGetContentPath(ArticleID => $Param{ArticleID});
     my %Index = ();
     my $Counter = 0;
     # try fs
     my @List = glob("$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/*");
-    foreach (@List) {
-        $Counter++;
-        my $FileSize = -s $_;
+    foreach my $Filename (@List) {
+        my $FileSize = -s $Filename;
         # human readable file size
         if ($FileSize) {
             # remove meta data in files
@@ -325,26 +393,42 @@ sub ArticleAttachmentIndex {
                 $FileSize = $FileSize.' Bytes';
             }
         }
+        # read content type
+        my $ContentType = '';
+        if (open(IN, "< $Filename")) {
+            while (<IN>) {
+                if ($ContentType) {
+                    last;
+                }
+                else {
+                    $ContentType = $_;
+                }
+            }
+            close(IN);
+        }
         # strip filename
-        s!^.*/!!;
-        if ($_ ne 'plain.txt') {
+        $Filename =~ s!^.*/!!;
+        if ($Filename ne 'plain.txt') {
             # add the info the the hash
+            $Counter++;
             $Index{$Counter} = {
-                Filename => $_,
+                Filename => $Filename,
                 Filesize => $FileSize,
+                ContentType => $ContentType,
             };
         }
 
     }
     # try database (if there is no index in fs)
     if (!%Index) {
+        foreach (qw(ArticleID)) {
+            $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+        }
         my $SQL = "SELECT filename, content_type, content_size FROM article_attachment ".
-        " WHERE ".
-        " article_id = ".$Self->{DBObject}->Quote($Param{ArticleID})."".
-        " ORDER BY id";
+          " WHERE ".
+          " article_id = $Param{ArticleID} ORDER BY id";
         $Self->{DBObject}->Prepare(SQL => $SQL);
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
-           $Counter++;
             # human readable file size
             if ($Row[2]) {
                 if ($Row[2] > (1024*1024)) {
@@ -358,6 +442,7 @@ sub ArticleAttachmentIndex {
                 }
             }
             # add the info the the hash
+            $Counter++;
             $Index{$Counter} = {
                 Filename => $Row[0],
                 ContentType => $Row[1],
@@ -400,9 +485,12 @@ sub ArticleAttachment {
     }
     else {
         # try database
+        foreach (qw(ArticleID)) {
+            $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+        }
         my $SQL = "SELECT content_type, content FROM article_attachment ".
-        " WHERE ".
-        " article_id = ".$Self->{DBObject}->Quote($Param{ArticleID})."";
+          " WHERE ".
+          " article_id = $Param{ArticleID}";
         $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Param{FileID});
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
             $Data{ContentType} = $Row[0];
