@@ -1,8 +1,8 @@
 # --
 # Kernel/System/User.pm - some user functions
-# Copyright (C) 2001-2005 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: User.pm,v 1.46 2005/08/18 06:57:52 martin Exp $
+# $Id: User.pm,v 1.50.2.1 2007/03/15 09:45:47 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,10 +15,48 @@ use strict;
 use Kernel::System::CheckItem;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.46 $';
+$VERSION = '$Revision: 1.50.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-# --
+=head1 NAME
+
+Kernel::System::User - user lib
+
+=head1 SYNOPSIS
+
+All user functions. E. g. to add and updated user and other functions.
+
+=head1 PUBLIC INTERFACE
+
+=over 4
+
+=cut
+
+=item new()
+
+create a object
+
+  use Kernel::Config;
+  use Kernel::System::Log;
+  use Kernel::System::DB;
+  use Kernel::System::User;
+
+  my $ConfigObject = Kernel::Config->new();
+  my $LogObject    = Kernel::System::Log->new(
+      ConfigObject => $ConfigObject,
+  );
+  my $DBObject = Kernel::System::DB->new(
+      ConfigObject => $ConfigObject,
+      LogObject => $LogObject,
+  );
+  my $UserObject = Kernel::System::User->new(
+      ConfigObject => $ConfigObject,
+      LogObject => $LogObject,
+      DBObject => $DBObject,
+  );
+
+=cut
+
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -26,15 +64,11 @@ sub new {
     # allocate new hash for object
     my $Self = {};
     bless ($Self, $Type);
-    # --
     # check needed objects
-    # --
     foreach (qw(DBObject ConfigObject LogObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
-    # --
     # get user table
-    # --
     $Self->{UserTable} = $Self->{ConfigObject}->Get('DatabaseUserTable')
       || 'user';
     $Self->{UserTableUserID} = $Self->{ConfigObject}->Get('DatabaseUserTableUserID')
@@ -43,9 +77,7 @@ sub new {
       || 'pw';
     $Self->{UserTableUser} = $Self->{ConfigObject}->Get('DatabaseUserTableUser')
       || 'login';
-    # --
     # load generator customer preferences module
-    # --
     my $GeneratorModule = $Self->{ConfigObject}->Get('User::PreferencesModule')
       || 'Kernel::System::User::Preferences::DB';
     eval "require $GeneratorModule";
@@ -55,7 +87,25 @@ sub new {
 
     return $Self;
 }
-# --
+
+=item GetUserData()
+
+get user data (UserLogin, UserFirstname, UserLastname, UserEmail, ...)
+
+    my %User = $UserObject->GetUserData(
+        UserID => 123,
+        Cached => 1, # not required -> 0|1
+    );
+
+    or
+
+    my %User = $UserObject->GetUserData(
+        User => 'franz',
+        Cached => 1, # not required -> 0|1
+    );
+
+=cut
+
 sub GetUserData {
     my $Self = shift;
     my %Param = @_;
@@ -84,7 +134,7 @@ sub GetUserData {
         $SQL .= " $Self->{UserTableUser} = '".$Self->{DBObject}->Quote($Param{User})."'";
     }
     else {
-        $SQL .= " $Self->{UserTableUserID} = ".$Self->{DBObject}->Quote($Param{UserID})."";
+        $SQL .= " $Self->{UserTableUserID} = ".$Self->{DBObject}->Quote($Param{UserID}, 'Integer')."";
     }
     $Self->{DBObject}->Prepare(SQL => $SQL);
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
@@ -132,21 +182,37 @@ sub GetUserData {
         $Preferences{UserEmail} = $Data{UserLogin};
     }
     # cache user result
-    if ($Param{User} && $Self->{'GetUserData::User::'.$Param{User}}) {
+    if ($Param{User}) {
         $Self->{'GetUserData::User::'.$Param{User}} = {%Data, %Preferences};
     }
-    elsif ($Param{UserID} && $Self->{'GetUserData::UserID::'.$Param{UserID}}) {
+    elsif ($Param{UserID}) {
         $Self->{'GetUserData::UserID::'.$Param{UserID}} = {%Data, %Preferences};
     }
     # return data
     return (%Data, %Preferences);
 }
-# --
+
+=item UserAdd()
+
+to add new users
+
+  my $UserID = $UserObject->UserAdd(
+      Firstname => 'Huber',
+      Lastname => 'Manfred',
+      Login => 'mhuber',
+      Pw => 'some-pass', # not required
+      Email => 'email@example.com',
+      ValidID => 1,
+      UserID => 123,
+  );
+
+=cut
+
 sub UserAdd {
     my $Self = shift;
     my %Param = @_;
     # check needed stuff
-    foreach (qw(Firstname Lastname Login Pw ValidID UserID Email)) {
+    foreach (qw(Firstname Lastname Login ValidID UserID Email)) {
       if (!$Param{$_}) {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
         return;
@@ -161,9 +227,16 @@ sub UserAdd {
         );
         return;
     }
+    # check password
+    if (!$Param{Pw}) {
+        $Param{Pw} = $Self->GenerateRandomPassword();
+    }
     # quote params
-    foreach (keys %Param) {
-       $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
+    foreach (qw(Salutation Firstname Lastname Login Pw)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
+    }
+    foreach (qw(ValidID UserID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
     my $SQL = "INSERT INTO $Self->{UserTable} " .
@@ -183,33 +256,50 @@ sub UserAdd {
        " current_timestamp, $Param{UserID})";
 
     if ($Self->{DBObject}->Do(SQL => $SQL)) {
-      # get new user id
-      $SQL = "SELECT $Self->{UserTableUserID} ".
-        " FROM " .
-        " $Self->{UserTable} " .
-        " WHERE " .
-        " $Self->{UserTableUser} = '$Param{Login}'";
-      my $UserID = '';
-      $Self->{DBObject}->Prepare(SQL => $SQL);
-      while (my @RowTmp = $Self->{DBObject}->FetchrowArray()) {
-        $UserID = $RowTmp[0];
-      }
-      # log notice
-      $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "User: '$Param{Login}' ID: '$UserID' created successfully ($Param{UserID})!",
-      );
-      # set password
-      $Self->SetPassword(UserLogin => $Param{Login}, PW => $Param{Pw});
-      # set email address
-      $Self->SetPreferences(UserID => $UserID, Key => 'UserEmail', Value => $Param{Email});
-      return $UserID;
+        # get new user id
+        $SQL = "SELECT $Self->{UserTableUserID} ".
+            " FROM " .
+            " $Self->{UserTable} " .
+            " WHERE " .
+            " $Self->{UserTableUser} = '$Param{Login}'";
+        my $UserID = '';
+        $Self->{DBObject}->Prepare(SQL => $SQL);
+        while (my @Row = $Self->{DBObject}->FetchrowArray()) {
+            $UserID = $Row[0];
+        }
+        # log notice
+        $Self->{LogObject}->Log(
+            Priority => 'notice',
+            Message => "User: '$Param{Login}' ID: '$UserID' created successfully ($Param{UserID})!",
+        );
+        # set password
+        $Self->SetPassword(UserLogin => $Param{Login}, PW => $Param{Pw});
+        # set email address
+        $Self->SetPreferences(UserID => $UserID, Key => 'UserEmail', Value => $Param{Email});
+        return $UserID;
     }
     else {
         return;
     }
 }
-# --
+
+=item UserUpdate()
+
+to update users
+
+  $UserObject->UserUpdate(
+      ID => 4321,
+      Firstname => 'Huber',
+      Lastname => 'Manfred',
+      Login => 'mhuber',
+      Pw => 'some-pass', # not required
+      Email => 'email@example.com',
+      ValidID => 1,
+      UserID => 123,
+  );
+
+=cut
+
 sub UserUpdate {
     my $Self = shift;
     my %Param = @_;
@@ -232,9 +322,12 @@ sub UserUpdate {
     # get old user data (pw)
     my %UserData = $Self->GetUserData(UserID => $Param{ID});
     # quote params
-    foreach (keys %Param) {
+    foreach (qw(Salutation Firstname Lastname)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) || '';
     }
+    foreach (qw(ID ValidID UserID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     # update db
     my $SQL = "UPDATE $Self->{UserTable} SET " .
         " salutation = '$Param{Salutation}', " .
@@ -264,6 +357,28 @@ sub UserUpdate {
         return;
     }
 }
+
+=item UserSearch()
+
+to search users
+
+  my %List = $UserObject->UserSearch(
+      Search => '*some*', # also 'hans+huber' possible
+      ValidID => 1, # not required
+  );
+
+  my %List = $UserObject->UserSearch(
+      UserLogin => '*some*',
+      ValidID => 1, # not required
+  );
+
+  my %List = $UserObject->UserSearch(
+      PostMasterSearch => 'email@example.com',
+      ValidID => 1, # not required
+  );
+
+=cut
+
 sub UserSearch {
     my $Self = shift;
     my %Param = @_;
@@ -276,7 +391,7 @@ sub UserSearch {
     }
     # build SQL string 1/2
     my $SQL = "SELECT $Self->{UserTableUser} ";
-    my @Fields = ('first_name', 'last_name', 'email');
+    my @Fields = ('first_name', 'last_name');
     if (@Fields) {
         foreach my $Entry (@Fields) {
             $SQL .= ", $Entry";
@@ -347,7 +462,18 @@ sub UserSearch {
     }
     return %Users;
 }
-# --
+
+=item SetPassword()
+
+to set users passwords
+
+  $UserObject->SetPassword(
+      UserLogin => 'some-login',
+      PW => 'some-new-password'
+  );
+
+=cut
+
 sub SetPassword {
     my $Self = shift;
     my %Param = @_;
@@ -401,8 +527,8 @@ sub SetPassword {
     )) {
         # log notice
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "User: '$Param{UserLogin}' changed password successfully!",
+            Priority => 'notice',
+            Message => "User: '$Param{UserLogin}' changed password successfully!",
         );
         return 1;
     }
@@ -410,7 +536,7 @@ sub SetPassword {
         return;
     }
 }
-# --
+# just for compat. - not longer used
 sub GetUserIdByName {
     my $Self = shift;
     my %Param = @_;
@@ -421,7 +547,7 @@ sub GetUserIdByName {
         return;
     }
     # db quote
-    foreach (keys %Param) {
+    foreach (qw(User)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
     }
     # build sql query
@@ -439,17 +565,17 @@ sub GetUserIdByName {
     }
     # return
     if ($ID) {
-      return $ID;
+        return $ID;
     }
     else {
-      $Self->{LogObject}->Log(
-        Priority => 'error',
-        Message => "No UserID found with User $Param{User}!",
-      );
-      return;
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message => "No UserID found with User $Param{User}!",
+        );
+        return;
     }
 }
-# --
+# just for compat. - not longer used
 sub GetUserByID {
     my $Self = shift;
     my %Param = @_;
@@ -459,6 +585,10 @@ sub GetUserByID {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Need UserID!");
         return;
     }
+    # db quote
+    foreach (qw(UserID)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
+    }
     # build sql query
     my $SQL = sprintf (
     "select %s from %s where %s='%s'",
@@ -473,17 +603,56 @@ sub GetUserByID {
     }
     # return
     if ($User) {
-      return $User;
+        return $User;
     }
     else {
-      $Self->{LogObject}->Log(
-        Priority => 'error',
-        Message => "No User found with ID $Param{UserID}!",
-      );
-      return;
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message => "No User found with ID $Param{UserID}!",
+        );
+        return;
     }
 }
-# --
+
+=item UserName()
+
+get user name
+
+  my $Name = $UserObject->UserName(
+      UserLogin => 'some-login',
+  );
+
+  or
+
+  my $Name = $UserObject->UserName(
+      UserID => 123,
+  );
+
+=cut
+
+sub UserName {
+    my $Self = shift;
+    my %Param = @_;
+    my %User = $Self->GetUserData(%Param);
+    if (%User) {
+        return "$User{UserFirstname} $User{UserLastname}";
+    }
+    else {
+        return;
+    }
+}
+
+=item UserList()
+
+return a hash with all users
+
+  my %List = $UserObject->UserList(
+      Type => 'Short', # Short|Long
+      Valid => 1, # not required
+  );
+
+=cut
+
 sub UserList {
     my $Self = shift;
     my %Param = @_;
@@ -506,7 +675,21 @@ sub UserList {
     );
     return %Users;
 }
-# --
+
+=item GenerateRandomPassword()
+
+generate a random password
+
+  my $Password = $UserObject->GenerateRandomPassword();
+
+  or
+
+  my $Password = $UserObject->GenerateRandomPassword(
+      Size => 16,
+  );
+
+=cut
+
 sub GenerateRandomPassword {
     my $Self = shift;
     my %Param = @_;
@@ -529,107 +712,69 @@ sub GenerateRandomPassword {
     # Return the password.
     return $Password;
 }
-# --
-sub SyncLDAP2Database {
-    my $Self = shift;
-    my %Param = @_;
-    # check needed stuff
-    if (!$Param{User}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need User!");
-        return;
-    }
-    # check if we run LDAP and add aproperiate data into the RDBMS
-    if ($Self->{ConfigObject}->Get('AuthModule') ne 'Kernel::System::Auth::LDAP') {
-        return 1;
-    }
-    # get LDAP variables
-    if (eval {'require Net::LDAP;'}) {
-        $Self->{Host} = $Self->{ConfigObject}->Get('AuthModule::LDAP::Host')
-          || die "Need AuthModule::LDAPHost in Kernel/Config.pm";
-        $Self->{BaseDN} = $Self->{ConfigObject}->Get('AuthModule::LDAP::BaseDN')
-          || die "Need AuthModule::LDAPBaseDN in Kernel/Config.pm";
-        $Self->{UID} = $Self->{ConfigObject}->Get('AuthModule::LDAP::UID')
-          || die "Need AuthModule::LDAPBaseDN in Kernel/Config.pm";
-        $Self->{SearchUserDN} = $Self->{ConfigObject}->Get('AuthModule::LDAP::SearchUserDN') || '';
-        $Self->{SearchUserPw} = $Self->{ConfigObject}->Get('AuthModule::LDAP::SearchUserPw') || '';
-        $Self->{GroupDN} = $Self->{ConfigObject}->Get('AuthModule::LDAP::GroupDN') || '';
-        $Self->{AccessAttr} = $Self->{ConfigObject}->Get('AuthModule::LDAP::AccessAttr') || '';
-        # Net::LDAP new params
-        if ($Self->{ConfigObject}->Get('AuthModule::LDAP::Params')) {
-            $Self->{Params} = $Self->{ConfigObject}->Get('AuthModule::LDAP::Params');
-        }
-        else {
-            $Self->{Params} = {};
-        }
-        # bind to LDAP
-        my $LDAP = Net::LDAP->new($Self->{Host}, %{$Self->{Params}}) or die "$@";
-        if (!$LDAP->bind(dn => $Self->{SearchUserDN}, password => $Self->{SearchUserPw})) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message => "First LDAP bind failed!",
-            );
-            return;
-        }
-        # --
-        # perform user search
-        # --
-        my $Filter = "($Self->{UID}=$Param{User})";
-        my $Result = $LDAP->search (
-            base   => $Self->{BaseDN},
-            filter => $Filter,
-        );
-        # --
-        # get whole user data
-        # --
-        my $UserDN = '';
-        my $UserPassword = '';
-        my %SyncUser = ();
-        foreach my $Entry ($Result->all_entries) {
-            $UserDN = $Entry->dn();
-            foreach (keys %{$Self->{ConfigObject}->Get('UserSyncLDAPMap')}) {
-                $SyncUser{$_} = $Entry->get_value($Self->{ConfigObject}->Get('UserSyncLDAPMap')->{$_});
-            }
-            $UserPassword = $Entry->get_value('userPassword') || $Self->GenerateRandomPassword();
-        }
-        if ($Self->UserAdd(
-            Salutation => 'Mr/Mrs',
-            Login => $Param{User},
-            Pw => $UserPassword,
-            %SyncUser,
-            UserType => 'User',
-            ValidID => 1,
-            UserID => 1,
-        )) {
-            $Self->{LogObject}->Log(
-                Priority => 'notice',
-                Message => "Data for '$Param{User} ($UserDN)' created in RDBMS, proceed.",
-            );
-            return 1;
-        }
-        else {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message => "Can't create user '$Param{User} ($UserDN)' in RDBMS!",
-            );
-            return;
-        }
-    }
-}
-# --
+
+=item SetPreferences()
+
+set user preferences
+
+  $UserObject->SetPreferences(
+      Key => 'UserComment',
+      Value => 'some comment',
+      UserID => 123,
+  );
+
+=cut
+
 sub SetPreferences {
     my $Self = shift;
     return $Self->{PreferencesObject}->SetPreferences(@_);
 }
-# --
+
+=item GetPreferences()
+
+get user preferences
+
+  my %Preferences = $UserObject->GetPreferences(
+      UserID => 123,
+  );
+
+=cut
+
 sub GetPreferences {
     my $Self = shift;
     return $Self->{PreferencesObject}->GetPreferences(@_);
 }
-# --
+
+=item SearchPreferences()
+
+search in user preferences
+
+  my %UserList = $Self->SearchPreferences(
+      Key => 'UserEmail',
+      Value => 'email@example.com',
+  );
+
+=cut
+
 sub SearchPreferences {
     my $Self = shift;
     return $Self->{PreferencesObject}->SearchPreferences(@_);
 }
-# --
 
 1;
+
+=head1 TERMS AND CONDITIONS
+
+This software is part of the OTRS project (http://otrs.org/).
+
+This software comes with ABSOLUTELY NO WARRANTY. For details, see
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+
+=cut
+
+=head1 VERSION
+
+$Revision: 1.50.2.1 $ $Date: 2007/03/15 09:45:47 $
+
+=cut
