@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # PostMaster.pl - the global eMail handle for email2db
-# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2006 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: PostMaster.pl,v 1.16.6.1 2004/09/16 07:50:47 martin Exp $
+# $Id: PostMaster.pl,v 1.19.2.1 2006/01/07 15:31:31 martin Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,11 +35,12 @@ use strict;
 umask 002;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.16.6.1 $';
+$VERSION = '$Revision: 1.19.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 use Getopt::Std;
 use Kernel::Config;
+use Kernel::System::Time;
 use Kernel::System::DB;
 use Kernel::System::Log;
 use Kernel::System::PostMaster;
@@ -51,7 +52,7 @@ my %Opts = ();
 getopt('hqtd', \%Opts);
 if ($Opts{'h'}) {
     print "PostMaster.pl <Revision $VERSION> - OTRS cmd postmaster\n";
-    print "Copyright (c) 2001-2003 Martin Edenhofer <martin\@otrs.org>\n";
+    print "Copyright (c) 2001-2005 Martin Edenhofer <martin\@otrs.org>\n";
     print "usage: PostMaster.pl -q <QUEUE> -t <TRUSTED> \n";
     exit 1;
 }
@@ -65,20 +66,24 @@ if (!$Opts{'q'}) {
     $Opts{'q'} = '';
 }
 
+# --
+# create common objects
+# --
+my %CommonObject = ();
+$CommonObject{ConfigObject} = Kernel::Config->new();
+$CommonObject{TimeObject} = Kernel::System::Time->new(
+    %CommonObject,
+);
+$CommonObject{LogObject} = Kernel::System::Log->new(
+    LogPrefix => 'OTRS-PM',
+    %CommonObject,
+);
 # Wrap the majority of the script in an "eval" block so that any
 # unexpected (but probably transient) fatal errors (such as the
 # database being unavailable) can be trapped without causing a
 # bounce
 eval {
-    # --
-    # create common objects
-    # --
-    my %CommonObject = ();
-    $CommonObject{ConfigObject} = Kernel::Config->new();
-    $CommonObject{LogObject} = Kernel::System::Log->new(
-        LogPrefix => 'OTRS-PM',
-        %CommonObject,
-    );
+    # create needed objects
     $CommonObject{DBObject} = Kernel::System::DB->new(%CommonObject);
     # debug info
     if ($Opts{'d'}) {
@@ -103,9 +108,9 @@ eval {
         Trusted => $Opts{'t'},
         Debug => $Opts{'d'},
     );
-    $CommonObject{PostMaster}->Run(
-        Queue => $Opts{'q'},
-    );
+    if (!$CommonObject{PostMaster}->Run(Queue => $Opts{'q'})) {
+        die "Can't process mail, see log sub system!";
+    }
 
     # debug info
     if ($Opts{'d'}) {
@@ -123,6 +128,10 @@ if ($@) {
     # it; see sysexits.h. Most mail programs will retry an
     # EX_TEMPFAIL delivery for about four days, then bounce the
     # message.)
+    $CommonObject{LogObject}->Log(
+        Priority => 'error',
+        Message => $@,
+    );
     exit 75;
 }
 
