@@ -1,20 +1,20 @@
 #!/usr/bin/perl -w
 # --
 # UnlockTickets.pl - to unlock tickets
-# Copyright (C) 2002-2003 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2006 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: UnlockTickets.pl,v 1.11 2003/01/23 22:50:08 martin Exp $
+# $Id: UnlockTickets.pl,v 1.19.2.1 2006/08/22 11:07:54 cs Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -29,68 +29,73 @@ use lib dirname($RealBin)."/Kernel/cpan-lib";
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.11 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
+$VERSION = '$Revision: 1.19.2.1 $';
+$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
+use Date::Pcalc qw(Delta_Days Add_Delta_Days Day_of_Week Day_of_Week_Abbreviation);
 use Kernel::Config;
+use Kernel::System::Time;
 use Kernel::System::Log;
 use Kernel::System::DB;
 use Kernel::System::Ticket;
 use Kernel::System::User;
+use Kernel::System::State;
+use Kernel::System::Lock;
+
+my $Debug = 0;
 
 # --
 # common objects
 # --
 my %CommonObject = ();
 $CommonObject{ConfigObject} = Kernel::Config->new();
+$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
 $CommonObject{LogObject} = Kernel::System::Log->new(
     LogPrefix => 'OTRS-UnlockTickets',
     %CommonObject,
 );
 $CommonObject{DBObject} = Kernel::System::DB->new(%CommonObject);
 $CommonObject{TicketObject} = Kernel::System::Ticket->new(%CommonObject);
-$CommonObject{UserObject} = Kernel::System::User->new(%CommonObject);  
+$CommonObject{UserObject} = Kernel::System::User->new(%CommonObject);
+$CommonObject{StateObject} = Kernel::System::State->new(%CommonObject);
+$CommonObject{LockObject} = Kernel::System::Lock->new(%CommonObject);
 
-my @ViewableLocks = @{$CommonObject{ConfigObject}->Get('ViewableLocks')};
-my @UnlockStats = @{$CommonObject{ConfigObject}->Get('UnlockStats')};
+my @UnlockStateIDs = $CommonObject{StateObject}->StateGetStatesByType(
+    Type => 'Unlock',
+    Result => 'ID',
+);
+my @ViewableLockIDs = $CommonObject{LockObject}->LockViewableLock(Type => 'ID');
 
 # --
 # check args
 # --
 my $Command = shift || '--help';
 print "UnlockTickets.pl <Revision $VERSION> - unlock tickets\n";
-print "Copyright (c) 2002 Martin Edenhofer <martin\@otrs.org>\n";
+print "Copyright (c) 2001-2004 Martin Edenhofer <martin\@otrs.org>\n";
 # --
 # unlock all tickets
 # --
 if ($Command eq '--all') {
     print " Unlock all tickets:\n";
     my @Tickets = ();
-    my $SQL = "SELECT st.tn, slt.name, st.ticket_answered, st.id, st.user_id FROM " .
-    " ticket as st, queue as sq, ticket_state tsd, ticket_lock_type slt " .
+    my $SQL = "SELECT st.tn, st.ticket_answered, st.id, st.user_id FROM " .
+    " ticket st, queue sq " .
     " WHERE " .
-    " st.ticket_state_id = tsd.id " .
-    " AND " .
     " st.queue_id = sq.id " .
     " AND " .
-    " st.ticket_lock_id = slt.id ".
-    " AND " .
-    " tsd.name IN ( ${\(join ', ', @UnlockStats)} ) " .
-    " AND " .
-    " slt.name NOT IN ( ${\(join ', ', @ViewableLocks)} ) ";
+    " st.ticket_lock_id NOT IN ( ${\(join ', ', @ViewableLockIDs)} ) ";
     $CommonObject{DBObject}->Prepare(SQL => $SQL);
     while (my @RowTmp = $CommonObject{DBObject}->FetchrowArray()) {
-#        print " Ticket: $RowTmp[0] State: $RowTmp[1] Answered: $RowTmp[2]\n";
         push (@Tickets, \@RowTmp);
     }
     foreach (@Tickets) {
         my @Row = @{$_};
         print " Unlocking ticket id $Row[0] ...";
-        if ($CommonObject{TicketObject}->SetLock(
-            TicketID => $Row[3],
+        if ($CommonObject{TicketObject}->LockSet(
+            TicketID => $Row[2],
             Lock => 'unlock',
             UserID => 1,
-        ) ) { 
+        ) ) {
             print " done.\n";
         }
         else {
@@ -105,39 +110,38 @@ if ($Command eq '--all') {
 elsif ($Command eq '--timeout') {
     print " Unlock old tickets:\n";
     my @Tickets = ();
-    my $SQL = "SELECT st.tn, slt.name, st.ticket_answered, st.id, st.timeout, ".
-    " sq.unlock_timeout, user_id ".
+    my $SQL = "SELECT st.tn, st.ticket_answered, st.id, st.timeout, ".
+    " sq.unlock_timeout  ".
     " FROM " .
-    " ticket as st, queue as sq, ticket_state tsd, ticket_lock_type slt " .
+    " ticket st, queue sq " .
     " WHERE " .
-    " st.ticket_state_id = tsd.id " .
-    " AND " .
     " st.queue_id = sq.id " .
     " AND " .
-    " st.ticket_lock_id = slt.id " .
-    " AND " .
     " st.ticket_answered != 1 ".
     " AND " .
     " sq.unlock_timeout != 0 " .
     " AND " .
-    " tsd.name IN ( ${\(join ', ', @UnlockStats)} ) " .
+    " st.ticket_state_id IN ( ${\(join ', ', @UnlockStateIDs)} ) " .
     " AND " .
-    " slt.name NOT IN ( ${\(join ', ', @ViewableLocks)} ) ";
+    " st.ticket_lock_id NOT IN ( ${\(join ', ', @ViewableLockIDs)} ) ";
     $CommonObject{DBObject}->Prepare(SQL => $SQL);
-    while (my @RowTmp = $CommonObject{DBObject}->FetchrowArray()) {
-#        print " Ticket: $RowTmp[0] State: $RowTmp[1] Answered: $RowTmp[2]\n";
-        if (($RowTmp[4] + ($RowTmp[5]*60)) <= time()) {
-            push (@Tickets, \@RowTmp);
+    while (my @Row = $CommonObject{DBObject}->FetchrowArray()) {
+        my $CountedTime = $CommonObject{TimeObject}->WorkingTime(
+            StartTime => $Row[3],
+            StopTime => $CommonObject{TimeObject}->SystemTime(),
+        );
+        if ($CountedTime >= $Row[4]*60) {
+            push (@Tickets, \@Row);
         }
     }
     foreach (@Tickets) {
         my @Row = @{$_};
         print " Unlocking ticket id $Row[0] ...";
-        if ($CommonObject{TicketObject}->SetLock(
-            TicketID => $Row[3],
+        if ($CommonObject{TicketObject}->LockSet(
+            TicketID => $Row[2],
             Lock => 'unlock',
             UserID => 1,
-        ) ) { 
+        ) ) {
             print " done.\n";
         }
         else {
@@ -147,14 +151,14 @@ elsif ($Command eq '--timeout') {
     exit (0);
 }
 # --
-# show usage 
+# show usage
 # --
 else {
     print "usage: $0 [options] \n";
     print "  Options are as follows:\n";
     print "  --help        display this option help\n";
     print "  --timeout     unlock old tickets\n";
-    print "  --all         unlock all ticksts (force)\n";
+    print "  --all         unlock all tickets (force)\n";
     exit (1);
 }
 # --
